@@ -22,16 +22,15 @@
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
-# include "config/sparc/biarch64.h"
 # include "config/vxworks-dummy.h"
+# include "config/sparc/biarch64.h"
 # include "config/sparc/sparc.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/sparc/sysv4.h"
 # include "config/gnu-user.h"
 # include "config/linux.h"
 # include "config/glibc-stdint.h"
-# include "config/sparc/default-64.h"
+# include "config/sparc/default64.h"
 # include "config/sparc/linux64.h"
 # include "config/sparc/tso.h"
 # include "config/initfini-array.h"
@@ -42,8 +41,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
